@@ -30,6 +30,7 @@ def load_protocols():
         if not line.strip(): break
         proto, num,_ = line.split(None,2)
         protocols[int(num)] = proto
+    protocols[0]='ip'
     f.close()
     return protocols
 
@@ -65,8 +66,18 @@ class Dumper:
         self.protocols = load_protocols()
 
     def set_where(self, start=None, end=None, filename=None,dirfiles=None, stdin=False):
-        """Set the timeframe of the nfdump query
-           Specify just the start date or both the start and end date
+        """Set the timeframe of the nfdump query.
+        Specify one of the following:
+
+            * The start date
+            * The start and end date
+            * one of the filename,dirfiles, or stdin options
+
+        :param start: Start date and time
+        :param end: Start date and time
+        :param filename: Search this single filename
+        :param dirfiles: Search this directory
+        :param stdin:    Search stdin
         """
         
         self.start = start
@@ -93,28 +104,55 @@ class Dumper:
         if stdin:
             self.filename = '-'
 
-    def make_query(self, q):
+    def _arg_escape(self, arg):
+        """Escape any arguments so that they can be passed over SSH"""
         if self.remote_host:
-            return commands.mkarg(q)
+            return commands.mkarg(arg)
         else:
-            return q
+            return arg
 
     def search(self, query='', aggregate=None, statistics=None, statistics_order=None,limit=None):
-        """Run nfdump with the following arguments:
-            * aggregate: (True OR comma sep string OR list) of 'srcip dstip srcport dstport'
-            * statistics Generate netflow statistics info
-                                one of srcip, dstip, ip, srcport, dstport, port
-                                srcas, dstas, as, inif , outif, proto
-            * statistics_order one of:
-                packets, bytes, flows, bps pps and bpp.
-            * limit number of results
-        """
+        """Run nfdump with the following arguments
 
+        :param query: The nfdump filter
+        :param aggregate: (True OR comma sep string OR list) of
+
+            * srcip     - Source IP Address
+            * dstip     - Destination IP Address
+            * srcport   - Source Port
+            * dstport   - Destination Port
+
+        :param statistics: Generate netflow statistics info, one of
+
+            * srcip     - Source IP Address
+            * dstip     - Destination IP Address
+            * ip        - Any IP Address
+            * srcport   - Source Port
+            * dstport   - Destination Port
+            * port      - Any Port
+            * srcas     - Source ASN
+            * dstas     - Destination ASN
+            * as        - Any ASN
+            * inif      - Incoming Interface
+            * outif     - Outgoing Interface
+            * proto     - Protocol
+
+        :param statistics_order: one of
+
+            * packets
+            * bytes
+            * flows
+            * bps       - Bytes Per Second
+            * pps       - Packers Per Second
+            * bpp.      - Bytes Per Packet
+
+        :param limit: number of results
+        """
 
         cmd = []
         if self.remote_host:
             cmd = ['ssh', self.remote_host]
-        cmd.extend(['nfdump', '-o', 'pipe', self.make_query(query)])
+        cmd.extend(['nfdump', '-q', '-o', 'pipe', self._arg_escape(query)])
 
         if self.filename:
             cmd.extend(['-r', self.filename])
@@ -142,7 +180,8 @@ class Dumper:
             else:
                 if ',' not in aggregate:
                     aggregate = ','.join(aggregate)
-                cmd.extend(["-a", "-A", aggregate])
+                aggregate = aggregate.replace(" ","")
+                cmd.extend(["-a", "-A", self._arg_escape(aggregate)])
 
         if limit:
             if statistics:
@@ -160,9 +199,15 @@ class Dumper:
             return self.parse_search(out)
 
     def parse_search(self, out):
+        #    snprintf(data_string, STRINGSIZE-1 ,"%i|%u|%u|%u|%u|%u|%u|%u|%u|%u|%u|%u|%u|%u|%u|%u|%u|%u|%u|%u|%u|%u|%llu|%llu",
+        #                0 af, 1 r->first, 2 r->msec_first ,3 r->last, 4 r->msec_last, 5 r->prot,
+        #                6 sa[0], 7 sa[1], 8 sa[2], 9 sa[3], 10 r->srcport, 11 da[0], 12 da[1], 13 da[2], 14 da[3], 15 r->dstport,
+        #                16 r->srcas, 17 r->dstas, 18 r->input, 19 r->output,
+        #                20 r->tcp_flags, 21 r->tos, 22 (unsigned long long)r->dPkts, 23 (unsigned long long)r->dOctets);
+
         for line in out:
             parts = line.split("|")
-            parts = [maybe_int(x) for x in parts]
+            parts = [int(x) for x in parts]
             if not len(parts) > 20:
                 continue
             row = {
@@ -175,12 +220,12 @@ class Dumper:
                 #'sa0':          parts[6],
                 #'sa1':          parts[7],
                 #'sa2':          parts[8],
-                'src':          IP(parts[9]),
+                'srcip':        IP(parts[9]),
                 'srcport':      parts[10],
                 #'da0':          parts[11],
                 #'da1':          parts[12],
                 #'da2':          parts[13],
-                'dst':          IP(parts[14]),
+                'dstip':          IP(parts[14]),
                 'dstport':      parts[15],
                 'srcas':        parts[16],
                 'dstas':        parts[17],
@@ -261,6 +306,13 @@ class Dumper:
         return ret
 
 def search_file(filename, query='', aggregate=None, statistics=None, statistics_order=None,limit=None):
+    """Search a single nfcapd file
+
+    :param filename: the file to search
+
+    The rest of the options are passed directly to :func:`Dumper.search`
+    """
+
     d = Dumper()
     d.set_where(filename=filename)
     return d.search(query, aggregate, statistics, statistics_order, limit)
